@@ -3,7 +3,7 @@
 #
 # Author: Slaven Rezic
 #
-# Copyright (C) 2017,2018 Slaven Rezic. All rights reserved.
+# Copyright (C) 2017,2018,2020 Slaven Rezic. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
@@ -15,7 +15,7 @@ package Doit::Deb; # Convention: all commands here should be prefixed with 'deb_
 
 use strict;
 use warnings;
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 use Doit::Log;
 use Doit::Util 'get_sudo_cmd';
@@ -140,7 +140,12 @@ sub deb_install_key {
 	if ($keyserver) {
 	    $self->system(get_sudo_cmd(), 'apt-key', 'adv', '--keyserver', $keyserver, '--recv-keys', $key);
 	} elsif ($url) {
-	    my @fetch_cmd = ('curl', '-fsSL', $url);
+	    my @fetch_cmd;
+	    if (-x "/usr/bin/curl") { # XXX avoid Doit::ExtCmd::is_in_path until remote sync issues with nested components are resolved
+		@fetch_cmd = ('curl', '-fsSL', $url);
+	    } else {
+		@fetch_cmd = ('wget', '-O-', $url); # other alternative would be lwp-request
+	    }
 	    my @add_cmd   = (get_sudo_cmd(), 'apt-key', 'add', '-');
 	    if ($self->is_dry_run) {
 		info "Fetch key using '@fetch_cmd' and add using '@add_cmd' (dry-run)";
